==> haskell-warp-3.2.22-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.22
id: warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W
key: warp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
abi: 1d9baf1f171c173416edccd3cf032c07
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
import-dirs: /usr/lib/ghc-8.4.3/site-local/warp-3.2.22
library-dirs: /usr/lib/ghc-8.4.3/site-local/warp-3.2.22
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/warp-3.2.22
hs-libraries: HSwarp-3.2.22-HD9A29cf5w3Jl1EwrKzX5W
depends:
    base-4.11.1.0 array-0.5.2.0 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0
    bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 ghc-prim-0.5.2.0
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    iproute-1.7.5-356POOO6lL4LoveByV2WS3
    http2-1.6.3-5EqmmwYtYi2ARcHu5zE8XA
    simple-sendfile-0.2.27-9xoboGayfPgDkHNFwbPIaJ
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh text-1.2.3.0
    streaming-commons-0.2.0.0-JgIXAI1RxNy4PvXEKvDakK
    vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu stm-2.4.5.0
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-date-0.0.7-I6rDRmfHgSSzlBim9IYdP
    network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0=3a6a6105842b972d51861c6c93221bbc
             bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg=92d097cad2581e79eea8c7ac3d9e40cc
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             iproute-1.7.5-356POOO6lL4LoveByV2WS3=4ea2908d16ba65647cbb9b9edc33d62e
             http2-1.6.3-5EqmmwYtYi2ARcHu5zE8XA=8d8b0d9e42fb336d118d1d6041ffa2ee
             simple-sendfile-0.2.27-9xoboGayfPgDkHNFwbPIaJ=45dcbef32178f5b76c4daea3ac454318
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             wai-3.2.1.2-BZpOn5OSZorCibTMFlKxoh=3c531a9c9dceb5cf3884617d81bc336d
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             streaming-commons-0.2.0.0-JgIXAI1RxNy4PvXEKvDakK=12e263684b9335842044eb218cab9a12
             vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu=c9da6017b26ba1d80e07a6a7ed88b617
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             http-date-0.0.7-I6rDRmfHgSSzlBim9IYdP=a23a5e3f85fd9e0f51829f8ab24cbd9b
             network-2.7.0.2-DrojrvFSQxn3NIxU0DhiNK=94d8930bfafd62e59b581d22ac71f05d
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.2.22-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: warp
version: 3.2.22
id: warp-3.2.22-9Sa98sG73Yd5Xx5pcRKECK
key: warp-3.2.22-9Sa98sG73Yd5Xx5pcRKECK
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Kazu Yamamoto, Matt Brown
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.
category: Web, Yesod
abi: bdef0a7b5c921aa7c0274c64a540fce4
exposed: True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal
hidden-modules: Network.Wai.Handler.Warp.Buffer
                Network.Wai.Handler.Warp.Conduit Network.Wai.Handler.Warp.Counter
                Network.Wai.Handler.Warp.Date Network.Wai.Handler.Warp.FdCache
                Network.Wai.Handler.Warp.File
                Network.Wai.Handler.Warp.FileInfoCache
                Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP2
                Network.Wai.Handler.Warp.HTTP2.EncodeFrame
                Network.Wai.Handler.Warp.HTTP2.File
                Network.Wai.Handler.Warp.HTTP2.HPACK
                Network.Wai.Handler.Warp.HTTP2.Manager
                Network.Wai.Handler.Warp.HTTP2.Receiver
                Network.Wai.Handler.Warp.HTTP2.Request
                Network.Wai.Handler.Warp.HTTP2.Sender
                Network.Wai.Handler.Warp.HTTP2.Types
                Network.Wai.Handler.Warp.HTTP2.Worker
                Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
                Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
                Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
                Network.Wai.Handler.Warp.Request
                Network.Wai.Handler.Warp.RequestHeader
                Network.Wai.Handler.Warp.Response
                Network.Wai.Handler.Warp.ResponseHeader
                Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
                Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Timeout
                Network.Wai.Handler.Warp.Types Network.Wai.Handler.Warp.Windows
                Network.Wai.Handler.Warp.WithApplication Paths_warp
                Network.Wai.Handler.Warp.MultiMap
import-dirs: /usr/lib/ghc-8.4.3/site-local/warp-3.2.22
library-dirs: /usr/lib/ghc-8.4.3/site-local/warp-3.2.22
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/warp-3.2.22
hs-libraries: HSwarp-3.2.22-9Sa98sG73Yd5Xx5pcRKECK
depends:
    base-4.11.1.0 array-0.5.2.0 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0
    bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 ghc-prim-0.5.2.0
    http-types-0.12.1-1oUxUhazPUgCQ1gvXYmDkl
    iproute-1.7.5-7ylePgAi0bMBypzzn6n60s
    http2-1.6.3-5EqmmwYtYi2ARcHu5zE8XA
    simple-sendfile-0.2.27-KRKlMiPFOZvCkqh7OC0lee
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    wai-3.2.1.2-1XwAhPRofKRC0k9o4fseI5 text-1.2.3.0
    streaming-commons-0.2.1.0-2p1V31CgrvQ29xI7AGVQlS
    vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu stm-2.4.5.0
    word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-date-0.0.7-I6rDRmfHgSSzlBim9IYdP
    network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             auto-update-0.1.4-7k5Okr80TfS9UGlvnbDZr0=3a6a6105842b972d51861c6c93221bbc
             bsb-http-chunked-0.0.0.2-EMX9KWsmrWC5IYdbJZoXpg=92d097cad2581e79eea8c7ac3d9e40cc
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             http-types-0.12.1-1oUxUhazPUgCQ1gvXYmDkl=af0d8a313e0ed8ed9a0049b93a58f62a
             iproute-1.7.5-7ylePgAi0bMBypzzn6n60s=239805a9f7f068726c32aad4fd444bf1
             http2-1.6.3-5EqmmwYtYi2ARcHu5zE8XA=8d8b0d9e42fb336d118d1d6041ffa2ee
             simple-sendfile-0.2.27-KRKlMiPFOZvCkqh7OC0lee=e86225e96c3d715abc3825a31ae54ec6
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             wai-3.2.1.2-1XwAhPRofKRC0k9o4fseI5=e9a4c85218d4e129756acb19c36705be
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             streaming-commons-0.2.1.0-2p1V31CgrvQ29xI7AGVQlS=55fc3d6308b576bd3d7447dfb36af07c
             vault-0.3.1.1-I1BsgFEfUrP7ZzNeEDleeu=c9da6017b26ba1d80e07a6a7ed88b617
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             word8-0.1.3-Psnh2l3FAaIFxTGKIJTuU=ebc90d010e749320c5d2c76b47a69695
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             http-date-0.0.7-I6rDRmfHgSSzlBim9IYdP=a23a5e3f85fd9e0f51829f8ab24cbd9b
             network-2.7.0.2-3zQTN3hKcaz6IkeyUSsRrW=69b658fb7f59eb9acbefe047d83e7e11
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html: /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
